/* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
 * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
*/



#ifndef GADMIN_DHCPD_commands_H
#define GADMIN_DHCPD_commands_H

extern struct w *widgets;

int run_command(gchar *command);
void run_command_show_err(gchar *command);
void show_info(char *content);
int file_exists(char *infile);
char * get_comments_for_host(char *host_name);
char * get_comments_for_scope(char *subnet, char *netmask, char *nic);
int is_selected_host(char *hostname, char *conf_line);
char * isolate_setting(char *input);
char * remove_semicolon(char *input);
void add_missing_values(gchar *conf);
void init_start(struct w *widgets);
void init_stop(struct w *widgets);

#endif
